;#
;# Retourne la liste ordonnee des noms de Modules
;# 
proc OS:Modules { {plat ""} } {
    set ret [list FoundationClasses \
	   ModelingData \
	   ModelingAlgorithms \
	   Visualization \
	   ApplicationFramework \
	   DataExchange \
	   Draw \
	   WOK \
	   ]
    if { $plat != "win64" } { lappend ret Wrappers }
    return $ret
}
